==> com.liferay.site.cms.site.initializer-1.0.18-sources.jar: com/liferay/site/cms/site/initializer/internal/frontend/data/set/view/table/VocabulariesCMSTableFDSView.java <==
/**
 * SPDX-FileCopyrightText: (c) 2025 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.site.cms.site.initializer.internal.frontend.data.set.view.table;

import com.liferay.frontend.data.set.view.FDSView;
import com.liferay.frontend.data.set.view.table.FDSTableSchema;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilder;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilderFactory;

import java.util.Locale;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Noor Najjar
 */
@Component(property = "frontend.data.set.name=test", service = FDSView.class)
public class VocabulariesCMSTableFDSView extends BaseCMSTableFDSView {

	@Override
	public FDSTableSchema getFDSTableSchema(Locale locale) {
		FDSTableSchemaBuilder fdsTableSchemaBuilder =
			_fdsTableSchemaBuilderFactory.create();

		return fdsTableSchemaBuilder.add(
			"name", "title",
			fdsTableSchemaField -> fdsTableSchemaField.setActionId(
				"edit"
			).setContentRenderer(
				"actionLink"
			).setSortable(
				true
			)
		).add(
			"numberOfTaxonomyCategories", "categories",
			fdsTableSchemaField -> fdsTableSchemaField.setActionId(
				"view-categories"
			).setContentRenderer(
				"actionLink"
			).setSortable(
				true
			)
		).add(
			"assetTypes", "type",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"customVocabularyRenderer"
			).setSortable(
				true
			)
		).add(
			"scopeKey", "space",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"spaceTableCellRenderer")
		).add(
			addDateFDSTableSchemaField("dateModified", "modified")
		).build();
	}

	@Reference
	private FDSTableSchemaBuilderFactory _fdsTableSchemaBuilderFactory;

}

==> com.liferay.site.cms.site.initializer-1.0.21-sources.jar: com/liferay/site/cms/site/initializer/internal/frontend/data/set/view/table/VocabulariesCMSTableFDSView.java <==
/**
 * SPDX-FileCopyrightText: (c) 2025 Liferay, Inc. https://liferay.com
 * SPDX-License-Identifier: LGPL-2.1-or-later OR LicenseRef-Liferay-DXP-EULA-2.0.0-2023-06
 */

package com.liferay.site.cms.site.initializer.internal.frontend.data.set.view.table;

import com.liferay.frontend.data.set.view.FDSView;
import com.liferay.frontend.data.set.view.table.FDSTableSchema;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilder;
import com.liferay.frontend.data.set.view.table.FDSTableSchemaBuilderFactory;
import com.liferay.frontend.data.set.view.table.LinkFDSTableSchemaField;

import java.util.Locale;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Noor Najjar
 */
@Component(property = "frontend.data.set.name=test", service = FDSView.class)
public class VocabulariesCMSTableFDSView extends BaseCMSTableFDSView {

	@Override
	public FDSTableSchema getFDSTableSchema(Locale locale) {
		FDSTableSchemaBuilder fdsTableSchemaBuilder =
			_fdsTableSchemaBuilderFactory.create();

		return fdsTableSchemaBuilder.add(
			"name", "title",
			fdsTableSchemaField -> fdsTableSchemaField.setActionId(
				"edit"
			).setContentRenderer(
				"actionLink"
			).setSortable(
				true
			)
		).add(
			_addViewCategoriesLinkFDSTableSchemaField()
		).add(
			"assetTypes", "type",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"customVocabularyRenderer"
			).setSortable(
				true
			)
		).add(
			"scopeKey", "space",
			fdsTableSchemaField -> fdsTableSchemaField.setContentRenderer(
				"spaceTableCellRenderer")
		).add(
			addDateFDSTableSchemaField("dateModified", "modified")
		).build();
	}

	private LinkFDSTableSchemaField
		_addViewCategoriesLinkFDSTableSchemaField() {

		LinkFDSTableSchemaField linkFDSTableSchemaField =
			new LinkFDSTableSchemaField();

		linkFDSTableSchemaField.setActionId(
			"view-categories"
		).setContentRenderer(
			"actionLink"
		).setFieldName(
			"numberOfTaxonomyCategories"
		).setLabel(
			"categories"
		).setSortable(
			true
		);

		linkFDSTableSchemaField.setDecoration("underline");
		linkFDSTableSchemaField.setDisplayType("unstyled");

		return linkFDSTableSchemaField;
	}

	@Reference
	private FDSTableSchemaBuilderFactory _fdsTableSchemaBuilderFactory;

}
